// java wrapper for vtkAbstractMapper3D object
//

package vtk;
import vtk.*;

public class vtkAbstractMapper3D extends vtkAbstractMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double[] GetBounds_2();
  public double[] GetBounds()
    { return GetBounds_2(); }

  private native void GetBounds_3(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_3(id0); }

  private native double[] GetCenter_4();
  public double[] GetCenter()
    { return GetCenter_4(); }

  private native void GetCenter_5(double id0[]);
  public void GetCenter(double id0[])
    { GetCenter_5(id0); }

  private native double GetLength_6();
  public double GetLength()
    { return GetLength_6(); }

  private native int IsARayCastMapper_7();
  public int IsARayCastMapper()
    { return IsARayCastMapper_7(); }

  private native int IsARenderIntoImageMapper_8();
  public int IsARenderIntoImageMapper()
    { return IsARenderIntoImageMapper_8(); }

  private native void GetClippingPlaneInDataCoords_9(vtkMatrix4x4 id0,int id1,double id2[]);
  public void GetClippingPlaneInDataCoords(vtkMatrix4x4 id0,int id1,double id2[])
    { GetClippingPlaneInDataCoords_9(id0,id1,id2); }

  public vtkAbstractMapper3D() { super(); }

  public vtkAbstractMapper3D(long id) { super(id); }

}
